@@ -26,6 +26,9 @@ pub mod windows;
 pub use crate::windows::WindowsMouseManager as Mouse;
 
 pub mod common;
+pub mod error;
+
+pub use common::MouseActions;
 
 #[cfg(test)]
 mod tests {
